==> bigdata-common-0.0.120-zgx-20210113.072239-1-sources.jar: cn/com/duiba/bigdata/common/biz/enums/DuibaInnerLogOfflineEnum.java <==
package cn.com.duiba.bigdata.common.biz.enums;

/**
 * @author xugf 2020-11-27
 * hologres表的所有字段说明，枚举字段需要与 HologresDimensionEnum 中的枚举字段相同
 */
public enum DuibaInnerLogOfflineEnum {

    DATE_PARTITION("date_partition", "按天分区，格式：yyyyMMdd"),

    UNIX_TIME("unix_time", "unix时间戳"),

    DATA_MD5("data_md5", "唯一键"),

    INNER_GROUP("inner_group", "公司业务分类，大类"),

    INNER_TYPE("inner_type", "日志分类，小类"),

    APP_ID("app_id", "媒体id"),

    SLOT_ID("slot_id", "广告位id"),

    ACTIVITY_ID("activity_id", "活动id"),

    COMPANY_ID("company_id", "生效的主体类型 1-杭州推啊，2-霍尔果斯推啊"),

    ADVERT_TYPE("advert_type", "广告类型 -1-互动式广告，4-展示广告，6-激励广告"),

    ADVERT_TRADE_TAG_ID("advert_trade_tag_id", "广告行业"),

    FORM_ADVERT("form_advert", "表单类广告 0表示非表单类广告 1表示表单类广告"),

    ADVERT_ID("advert_id", "广告id"),

    ORIENTATION_ID("orientation_id", "广告定向配置id 0为默认配置"),

    ADVERT_RESOURCE_TAG_ID("advert_resource_tag_id", "广告资源id"),

    IS_FREE("is_free", "是否免费广告 0:收费 1:免费"),

    TARGET_EFFECT_TYPE("target_effect_type", "广告目标转化类型"),

    AE_AREA("ae_area", "运营区域 1-华东，2-华北 3-其他"),

    AE_ID("ae_id", "运营人员id"),

    MATERIAL_ID("material_id", "素材ID"),

    ACCOUNT_ID("account_id", "广告主账户id"),

    AGENT_ID("agent_id", "代理商id"),

    APP_SOURCE("app_source", "创建App的来源  0：积分商城（兑吧） 1：广告平台（推啊）"),

    APP_LEVEL("app_level", "媒体性质 1-在线KA,2-潜力KA,3-普通媒体"),

    DEVELOPER_ID("developer_id", "媒体账号id"),

    APP_FIRST_TRADE_ID("app_first_trade_id", "媒体一级行业"),

    APP_SECOND_TRADE_ID("app_second_trade_id", "媒体二级行业"),

    APP_FLOW_TAG("app_flow_tag", "媒体流量标签"),

    SLOT_MATERIAL_ID("slot_material_id", "广告位素材id"),

    SLOT_MATERIAL_PUT_TYPE("slot_material_put_type", "广告位素材投放方式 0-人工 1-算法1.0 2-算法2.0 3-算法返回null降级"),

    ACTIVITY_SOURCE("activity_source", "活动来源 0-兑吧 1-推啊"),

    ACTIVITY_TYPE("activity_type", "广告位投放活动类型 1-常规活动，2-自定义活动（非深度），3-直投页，4-深度互动，5-原生互动，6-激励互动"),

    ACTIVITY_PUT_TYPE("activity_put_type", "活动投放方式-大类 1:测试 2:算法 3:灰度测试 4:手投"),

    ACTIVITY_RELEASE_SUB_MODE("activity_release_sub_mode", "广告位上直投活动的投放方式 仅投1 优投人工2 优投算法3 纯算法4 其他0"),

    FLOW_TYPE("flow_type", "流量类型 1:sdk 2:adx 3:其它"),

    RISK_TYPE("risk_type", "风控类型 0：正常，1：用户作弊，2：广告位作弊"),

    DSM2_A("dsm2_a", "资源位类型 1-广告位直投,2-浮标,3-推荐弹层,4-一次返回拦截,5-谢谢参与推荐弹层 7-二次返回拦截 9-三次返回拦截"),

    FEE("fee", "广告消耗，单位分"),





    ;


    //hologres 中表定义的字段名称
    private String tableFieldName;

    //字段备注
    private String desc;

    DuibaInnerLogOfflineEnum(String tableFieldName, String desc) {
        this.tableFieldName = tableFieldName;
        this.desc = desc;
    }

    public String getTableFieldName() {
        return tableFieldName;
    }

    public String getDesc() {
        return desc;
    }
}

==> bigdata-common-0.0.121-zgx-20210115.035232-2-sources.jar: cn/com/duiba/bigdata/common/biz/enums/DuibaInnerLogOfflineEnum.java <==
package cn.com.duiba.bigdata.common.biz.enums;

/**
 * @author xugf 2020-11-27
 * hologres表的所有字段说明，枚举字段需要与 HologresDimensionEnum 中的枚举字段相同
 */
public enum DuibaInnerLogOfflineEnum {

    DATE_PARTITION("date_partition", "按天分区，格式：yyyyMMdd"),

    UNIX_TIME("unix_time", "unix时间戳"),

    DATA_MD5("data_md5", "唯一键"),

    INNER_GROUP("inner_group", "公司业务分类，大类"),

    INNER_TYPE("inner_type", "日志分类，小类"),

    APP_ID("app_id", "媒体id"),

    SLOT_ID("slot_id", "广告位id"),

    ACTIVITY_ID("activity_id", "活动id"),

    COMPANY_ID("company_id", "生效的主体类型 1-杭州推啊，2-霍尔果斯推啊"),

    ADVERT_TYPE("advert_type", "广告类型 -1-互动式广告，4-展示广告，6-激励广告"),

    ADVERT_TRADE_TAG_ID("advert_trade_tag_id", "广告行业"),

    FORM_ADVERT("form_advert", "表单类广告 0表示非表单类广告 1表示表单类广告"),

    ADVERT_ID("advert_id", "广告id"),

    ORIENTATION_ID("orientation_id", "广告定向配置id 0为默认配置"),

    ADVERT_RESOURCE_TAG_ID("advert_resource_tag_id", "广告资源id"),

    IS_FREE("is_free", "是否免费广告 0:收费 1:免费"),

    TARGET_EFFECT_TYPE("target_effect_type", "广告目标转化类型"),

    AE_AREA("ae_area", "运营区域 1-华东，2-华北 3-其他"),

    AE_ID("ae_id", "运营人员id"),

    MATERIAL_ID("material_id", "素材ID"),

    ACCOUNT_ID("account_id", "广告主账户id"),

    AGENT_ID("agent_id", "代理商id"),

    APP_SOURCE("app_source", "创建App的来源  0：积分商城（兑吧） 1：广告平台（推啊）"),

    APP_LEVEL("app_level", "媒体性质 1-在线KA,2-潜力KA,3-普通媒体"),

    DEVELOPER_ID("developer_id", "媒体账号id"),

    APP_FIRST_TRADE_ID("app_first_trade_id", "媒体一级行业"),

    APP_SECOND_TRADE_ID("app_second_trade_id", "媒体二级行业"),

    APP_FLOW_TAG("app_flow_tag", "媒体流量标签"),

    SLOT_MATERIAL_ID("slot_material_id", "广告位素材id"),

    SLOT_MATERIAL_PUT_TYPE("slot_material_put_type", "广告位素材投放方式 0-人工 1-算法1.0 2-算法2.0 3-算法返回null降级"),

    ACTIVITY_SOURCE("activity_source", "活动来源 0-兑吧 1-推啊"),

    ACTIVITY_TYPE("activity_type", "广告位投放活动类型 1-常规活动，2-自定义活动（非深度），3-直投页，4-深度互动，5-原生互动，6-激励互动"),

    ACTIVITY_PUT_TYPE("activity_put_type", "活动投放方式-大类 1:测试 2:算法 3:灰度测试 4:手投"),

    ACTIVITY_RELEASE_SUB_MODE("activity_release_sub_mode", "广告位上直投活动的投放方式 仅投1 优投人工2 优投算法3 纯算法4 其他0"),

    FLOW_TYPE("flow_type", "流量类型 1:sdk 2:adx 3:其它"),

    RISK_TYPE("risk_type", "风控类型 0：正常，1：用户作弊，2：广告位作弊"),

    DSM2_A("dsm2_a", "资源位类型 1-广告位直投,2-浮标,3-推荐弹层,4-一次返回拦截,5-谢谢参与推荐弹层 7-二次返回拦截 9-三次返回拦截"),

    FEE("fee", "广告消耗，单位分")





    ;


    //hologres 中表定义的字段名称
    private String tableFieldName;

    //字段备注
    private String desc;

    DuibaInnerLogOfflineEnum(String tableFieldName, String desc) {
        this.tableFieldName = tableFieldName;
        this.desc = desc;
    }

    public String getTableFieldName() {
        return tableFieldName;
    }

    public String getDesc() {
        return desc;
    }
}
